@@ -929,6 +929,8 @@ def cmdnext(ui, repo, **opts):
                 ui.warn(_(b"explicitly update to one of them\n"))
                 return 1
             else:
+                if selectedrev in aspchildren:
+                    return _nextevolve(ui, repo, selectedrev, opts)
                 return _updatetonext(ui, repo, repo[selectedrev], display, opts)
         else:
             if not opts['evolve'] or not aspchildren:
